/**
 * Bull SAS / OW2 Orchestra
 * Copyright (C) 2010 Bull S.A.S, and individual contributors as indicated
 * by the @authors tag.
 *
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/
package org.ow2.orchestra.jaxb.bpmn.marshaller;

/**
 * Class used to map BPMN namespaces into prefixes.
 *
 * @author Loic Albertin
 */
public final class NamespacePrefixMapper extends com.sun.xml.bind.marshaller.NamespacePrefixMapper {

  private static final String MODEL_NAMESPACE = "http://www.omg.org/spec/BPMN/20100524/MODEL";

  private static final String MODEL_DI_NAMESPACE = "http://www.omg.org/spec/BPMN/20100524/DI";

  private static final String DC_NAMESPACE = "http://www.omg.org/spec/DD/20100524/DC";

  private static final String DI_NAMESPACE = "http://www.omg.org/spec/DD/20100524/DI";

  /**
   * {@inheritDoc}
   *
   * @see com.sun.xml.bind.marshaller.NamespacePrefixMapper#getPreferredPrefix(java.lang.String,
   *      java.lang.String, boolean)
   */
  @Override
  public String getPreferredPrefix(String namespaceUri, String suggestion, boolean requirePrefix) {
    if (namespaceUri.equals(MODEL_NAMESPACE)) {
      return "bpmn";
    } else if (namespaceUri.equals(MODEL_DI_NAMESPACE)) {
      return "bpmndi";
    } else if (namespaceUri.equals(DI_NAMESPACE)) {
      return "di";
    } else if (namespaceUri.equals(DC_NAMESPACE)) {
      return "dc";
    } else {
      if (!requirePrefix) {
        // The first unknown prefix will be the default one
        return "";
      } else {
        // If default prefix is already used returns the suggested one
        return suggestion;
      }
    }
  }

}
